/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.ejb3.test.factory;

/**
 * Comment
 *
 * @author <a href="mailto:bill@jboss.org">Bill Burke</a>
 * @version $Revision: 1.2.2.4 $
 */
public interface Session2
{
   Entity1 find1FromManager(int id);

   void find1FromFactory(int id);

   Entity2 find2FromManager(int id);

   void find2FromFactory(int id);

   Util findUtil1FromManager(int id);

   Util findUtil2FromManager(int id);
}
